==> webservices-rt-2.1-sources.jar: com/sun/xml/ws/rx/mc/dev/AdditionalResponses.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.xml.ws.rx.mc.dev;

import com.sun.istack.NotNull;
import com.sun.xml.ws.api.PropertySet;
import com.sun.xml.ws.api.message.Packet;
import java.util.LinkedList;
import java.util.Queue;

/**
 *
 * @author Marek Potociar (marek.potociar at sun.com)
 */
public final class AdditionalResponses extends PropertySet {
    public static final String ADDITIONAL_RESPONSE_QUEUE = "com.sun.xml.ws.rx.mc.api.AditionalResponses.ADDITIONAL_RESPONSE_QUEUE";

    private final Queue<Packet> additionalResponsePacketQueue;

    public AdditionalResponses() {
        additionalResponsePacketQueue = new LinkedList<Packet>();
    }

    public static PropertyMap getMODEL() {
        return MODEL;
    }

    @Property(ADDITIONAL_RESPONSE_QUEUE)
    public @NotNull Queue<Packet> getAdditionalResponsePacketQueue() {
        return additionalResponsePacketQueue;
    }

    // The next lines implement the required PropertySet contract as described
    // in the PropertySet.getPropertyMap() javadoc

    private static final PropertyMap MODEL;

    static {
        MODEL = parse(AdditionalResponses.class);
    }

    @Override
    protected PropertyMap getPropertyMap() {
        return MODEL;
    }
}

==> webservices-rt-2.4.6-sources.jar: com/sun/xml/ws/rx/mc/dev/AdditionalResponses.java <==
/*
 * Copyright (c) 1997, 2021 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.ws.rx.mc.dev;

import com.oracle.webservices.api.message.BasePropertySet;
import com.sun.istack.NotNull;
import com.sun.xml.ws.api.message.Packet;
import java.lang.invoke.MethodHandles;
import java.util.LinkedList;
import java.util.Queue;

/**
 *
 * @author Marek Potociar (marek.potociar at sun.com)
 */
public final class AdditionalResponses extends BasePropertySet {
    public static final String ADDITIONAL_RESPONSE_QUEUE = "com.sun.xml.ws.rx.mc.api.AditionalResponses.ADDITIONAL_RESPONSE_QUEUE";

    private final Queue<Packet> additionalResponsePacketQueue;

    public AdditionalResponses() {
        additionalResponsePacketQueue = new LinkedList<Packet>();
    }

    public static PropertyMap getMODEL() {
        return MODEL;
    }

    @Property(ADDITIONAL_RESPONSE_QUEUE)
    public @NotNull Queue<Packet> getAdditionalResponsePacketQueue() {
        return additionalResponsePacketQueue;
    }

    // The next lines implement the required PropertySet contract as described
    // in the PropertySet.getPropertyMap() javadoc

    private static final PropertyMap MODEL;

    static {
        MODEL = parse(AdditionalResponses.class, MethodHandles.lookup());
    }

    @Override
    protected PropertyMap getPropertyMap() {
        return MODEL;
    }
}
